.. gmtorch documentation master file, created by
   sphinx-quickstart on Wed Nov  5 11:44:13 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root ``toctree`` directive.

gmtorch documentation
=====================

Welcome to gmtorch's documentation!

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   reference/modules

